# Howler.js for playing audio with the Web Audio API
# https://howlerjs.com/
howler = require('myModule').howler

# Disabling the preloader
Framer.Extras.Preloader.disable()

# Page 1: Bridge video
page_1 = new Layer
	size: Screen.size
	backgroundColor: null

Video_1_Bridge = new VideoLayer
	size: Screen.size
	video: "images/Video_1_Bridge.mp4"
	backgroundColor: null
	parent: page_1
Video_1_Bridge.player.loop = yes

Create_amazing_handheld = new Layer
	width: 512/2
	height: 122/2
	image: "images/Create_amazing_handheld.png"
	x: Align.center
	y: 41.5
	opacity: 0.8
	parent: page_1

Swipe_to_continue = new Layer
	width: 400/2
	height: 115/2
	image: "images/Swipe_to_continue.png"
	x: Align.center
	maxY: Screen.height - 100
	originY: 1
	parent: page_1
	scale: .5
	opacity: 0

# Show ‘Swipe to continue’
showSwipeToContinue = new Animation Swipe_to_continue,
	scale: 1
	opacity: 1
	options:
		curve: Spring
		time: 0.7

# Hide ‘Swipe to continue’
hideSwipeToContinue = new Animation Swipe_to_continue,
	scale: .5
	opacity: 0
	options:
		curve: Spring
		time: 0.7
		delay: 3

# Trigger «hideSwipeToContinue» when «showSwipeToContinue» ends
showSwipeToContinue.onAnimationEnd hideSwipeToContinue.start

# Page 2: Clouds video
page_2 = new Layer
	size: Screen.size
	backgroundColor: null

Video_2_Clouds = new VideoLayer
	size: Screen.size
	video: "images/Video_2_Clouds.mp4"
	backgroundColor: null
	parent: page_2
Video_2_Clouds.player.loop = yes

Hyperlapse_stabilizes_your_video = new Layer
	width: 534/2
	height: 104/2
	image: "images/Hyperlapse_stabilizes_your_video.png"
	x: Align.center
	y: 47.5
	opacity: 0.8
	parent: page_2

# Page 3: Train video
page_3 = new Layer
	size: Screen.size
	backgroundColor: null

Video_3_train = new VideoLayer
	size: Screen.size
	video: "images/Video_3_train.mp4"
	backgroundColor: null
	parent: page_3
Video_3_train.player.loop = yes

Share_your_hyperlapses_with = new Layer
	width: 539/2
	height: 104/2
	image: "images/Share_your_hyperlapses_with.png"
	x: Align.center
	y: 47.5
	opacity: 0.8
	parent: page_3

# Page 4: People dancing video
page_4 = new Layer
	size: Screen.size
	backgroundColor: null

Video_4_people = new VideoLayer
	size: Screen.size
	video: "images/Video_4_people.mp4"
	backgroundColor: null
	parent: page_4
Video_4_people.player.loop = yes

Get_started_by_letting_Hyperlapse = new Layer
	width: 530/2
	height: 105/2
	image: "images/Get_started_by_letting_Hyperlapse.png"
	x: Align.center
	y: 47.5
	opacity: 0.8
	parent: page_4

Allow_access = new Layer
	width: 440/2
	height: 100/2
	image: "images/Allow_access.png"
	x: Align.center
	y: 124.5
	parent: page_4

# Carousel for the 4 video pages
page = new PageComponent
	size: Screen.size
	scrollVertical: no
	x: Screen.width

# Add the pages to the PageComponent
page.addPage page_1
page.addPage page_2
page.addPage page_3
page.addPage page_4

# Disable overdrag
page.content.draggable.overdrag = no

# Page indicators
amount = 4
dotWidth = 8
spaceWidth = 8

allDots = amount * dotWidth
allSpaces = ( amount - 1 ) * spaceWidth
allDotsAndSpaces = allDots + allSpaces
first_x = Screen.midX - ( allDotsAndSpaces / 2 )

allSolidDots = []

for i in [0...amount]
	# empty page indicators
	dot_hollow = new Layer
		size: 8
		image: "images/dot_hollow.png"
		x: first_x + ( i * (dotWidth + spaceWidth) )
		maxY: Screen.height - 50
		parent: page
	
	# filled page indicators
	dot_filled = new Layer
		size: 8
		image: "images/dot_filled.png"
		x: first_x + ( i * (dotWidth + spaceWidth) )
		maxY: Screen.height - 50
		parent: page
		opacity: 0
	
	dot_filled.states.active =
		opacity: 1
	dot_filled.animationOptions = time: 0.5
	
	# Store solid dot in the array
	allSolidDots.push dot_filled

# Make first page indicator active
allSolidDots[0].stateSwitch "active"

# Splash screen
splash_screen = new Layer
	size: Screen.size
	image: "images/splash_screen.png"

spinning_wheel = new Layer
	size: Screen.width / 3.07
	image: "images/spinning_wheel.png"
	x: Align.center
	y: Screen.height / 2.84
	parent: splash_screen

# Start spinning the wheel after 2 seconds
Utils.delay 2, ->
	spinning_wheel.animate
		rotation: 360*15
		options:
			time: 5
			curve: Bezier.easeIn
	
	# slide to the videos after 3.3 seconds more
	splash_screen.animate
		x: -Screen.width
		options:
			curve: Spring(damping: 0.8)
			time: 0.5
			delay: 3.3
	
	page.animate
		x: 0
		options:
			curve: Spring(damping: 0.8)
			time: 0.5
			delay: 3.3

# Start the first video
Utils.delay 5.2, ->
	Video_1_Bridge.player.play()
	# and preload the other videos
	Utils.delay 1, ->
		Video_2_Clouds.player.load()
		Video_3_train.player.load()
		Video_4_people.player.load()
	# Start the music
	music_1.play()
	music_2.play()
	music_3.play()
	music_4.play()
	# … but mute 3 tracks
	music_2.mute yes
	music_3.mute yes
	music_4.mute yes

# Make ‘Swipe to continue’ appear
user_has_swiped = no

# User hasn’t swiped after ± 10 sec of 1st video?
# -> tell them to swipe
Utils.delay 15, ->
	if user_has_swiped is no
		showSwipeToContinue.start()

# The music in 4 looping tracks
music_1 = new Howl
	src: ["sounds/music_1.wav"]
	loop: yes
music_2 = new Howl
	src: ["sounds/music_2.wav"]
	loop: yes
music_3 = new Howl
	src: ["sounds/music_3.wav"]
	loop: yes
music_4 = new Howl
	src: ["sounds/music_4.wav"]
	loop: yes

# Listen to page changes
page.on "change:currentPage", ->
	user_has_swiped = yes
	page_index = page.horizontalPageIndex page.currentPage
	
	switch page_index
		when 0
			Video_1_Bridge.player.play()
			music_2.mute yes
		when 1
			music_2.mute no
			Video_2_Clouds.player.play()
			music_3.mute yes
		when 2
			music_3.mute no
			Video_3_train.player.play()
			music_4.mute yes
		when 3
			music_4.mute no
			Video_4_people.player.play()
	
	for i in [0..page_index]
		allSolidDots[i].animate "active"
	
	if page_index < 3
		for i in [page_index..2]
			allSolidDots[i+1].animate "default"

# Double-tap to stop the music
page.onDoubleTap ->
	music_1.pause()
	music_2.pause()
	music_3.pause()
	music_4.pause()
